@@ -25,9 +25,8 @@
 #' @param colors vector of custom points colors. Colors must be defined as an
 #'     hexadecimal string (eg "#FF0000"). If \code{colors} is a named list or
 #'     a named vector, then the colors will be associated with their name
-#'     within \code{col_var}. For a continuous color scale, can be a string giving
-#'     the interpolate function name from d3-scale-chromatic (for example,
-#'     "interpolatePurples")
+#'     within \code{col_var}. A string can be given to specify a d3-scale-chromatic
+#'     function name (for example, "interpolatePurples" or "schemeTableau10")
 #' @param ellipses draw confidence ellipses for points or the different color
 #'     mapping groups
 #' @param ellipses_level confidence level for ellipses (0.95 by default)
@@ -462,16 +461,20 @@ scatterD3 <- function(x, y, data = NULL, lab = NULL,
 
     ## create widget
     htmlwidgets::createWidget(
-                     name = 'scatterD3',
-                     x,
-                     width = width,
-                     height = height,
-                     package = 'scatterD3',
-                     sizingPolicy = htmlwidgets::sizingPolicy(
-                                                     browser.fill = TRUE,
-                                                     viewer.fill = TRUE
-                                                 )
-                 )
+        name = 'scatterD3',
+        x,
+        width = width,
+        height = height,
+        package = 'scatterD3',
+        sizingPolicy = htmlwidgets::sizingPolicy(
+            browser.fill = TRUE,
+            browser.defaultWidth = "100%",
+            browser.defaultHeight = "85vh",
+            viewer.fill = TRUE,
+            viewer.defaultWidth = "100%",
+            viewer.defaultHeight = "85vh"
+        )
+    )
 }
 
 #' @rdname scatterD3-shiny
